==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureWorkloadContainerAutoProtectionIntentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ProtectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure workload specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'AzureWorkloadContainerAutoProtectionIntent'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureWorkloadContainerAutoProtectionIntentArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val itemId: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val protectionIntentItemType: Output<String>,
    public val protectionState: Output<Either<String, ProtectionStatus>>? = null,
    public val sourceResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .itemId(itemId?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .protectionIntentItemType(protectionIntentItemType.applyValue({ args0 -> args0 }))
            .protectionState(
                protectionState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureWorkloadContainerAutoProtectionIntentArgs].
 */
@PulumiTagMarker
public class AzureWorkloadContainerAutoProtectionIntentArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var itemId: Output<String>? = null

    private var policyId: Output<String>? = null

    private var protectionIntentItemType: Output<String>? = null

    private var protectionState: Output<Either<String, ProtectionStatus>>? = null

    private var sourceResourceId: Output<String>? = null

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("ppjgaiefsrvjoemh")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("gypqnovrfmvvgwvq")
    public suspend fun itemId(`value`: Output<String>) {
        this.itemId = value
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("ynxmduxnwfxalvoc")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadContainerAutoProtectionIntent'.
     */
    @JvmName("fpsastbvrkbphmgp")
    public suspend fun protectionIntentItemType(`value`: Output<String>) {
        this.protectionIntentItemType = value
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("uyrellpctyfkyabb")
    public suspend fun protectionState(`value`: Output<Either<String, ProtectionStatus>>) {
        this.protectionState = value
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("vkklhbbapxvedkqm")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("weecftgepirgdsof")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("lsohrxburtmlkdar")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("hljxlkkxvaeuonak")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("cdfbuowyagtrlrsn")
    public suspend fun itemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.itemId = mapped
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("nnumuoxtwtapyvcy")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadContainerAutoProtectionIntent'.
     */
    @JvmName("gktflhwscospeckj")
    public suspend fun protectionIntentItemType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionIntentItemType = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("piliqmllulywrdom")
    public suspend fun protectionState(`value`: Either<String, ProtectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("xjokyitvuwjbvjjc")
    public fun protectionState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("wkdhssbyfynjbyjk")
    public fun protectionState(`value`: ProtectionStatus) {
        val toBeMapped = Either.ofRight<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("adkbgqiqtjtynbio")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    internal fun build(): AzureWorkloadContainerAutoProtectionIntentArgs =
        AzureWorkloadContainerAutoProtectionIntentArgs(
            backupManagementType = backupManagementType,
            itemId = itemId,
            policyId = policyId,
            protectionIntentItemType = protectionIntentItemType ?: throw
                PulumiNullFieldException("protectionIntentItemType"),
            protectionState = protectionState,
            sourceResourceId = sourceResourceId,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureWorkloadContainerAutoProtectionIntentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ProtectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure workload specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'AzureWorkloadContainerAutoProtectionIntent'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureWorkloadContainerAutoProtectionIntentArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val itemId: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val protectionIntentItemType: Output<String>,
    public val protectionState: Output<Either<String, ProtectionStatus>>? = null,
    public val sourceResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadContainerAutoProtectionIntentArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .itemId(itemId?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .protectionIntentItemType(protectionIntentItemType.applyValue({ args0 -> args0 }))
            .protectionState(
                protectionState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureWorkloadContainerAutoProtectionIntentArgs].
 */
@PulumiTagMarker
public class AzureWorkloadContainerAutoProtectionIntentArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var itemId: Output<String>? = null

    private var policyId: Output<String>? = null

    private var protectionIntentItemType: Output<String>? = null

    private var protectionState: Output<Either<String, ProtectionStatus>>? = null

    private var sourceResourceId: Output<String>? = null

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("rcybfhibngsrlawb")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("dggperfhhnucxyqj")
    public suspend fun itemId(`value`: Output<String>) {
        this.itemId = value
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("rojedjjggcwlnadm")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadContainerAutoProtectionIntent'.
     */
    @JvmName("xuvnxvpnepjypmru")
    public suspend fun protectionIntentItemType(`value`: Output<String>) {
        this.protectionIntentItemType = value
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("olwwguffwbshklom")
    public suspend fun protectionState(`value`: Output<Either<String, ProtectionStatus>>) {
        this.protectionState = value
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("eofqpywkqthfynws")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("tvcrdoggqjrnfxua")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("yctawjsfkidxygga")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("tcrghbvcgjuaxxoh")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("mlctwbwffhcyquar")
    public suspend fun itemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.itemId = mapped
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("hlaywmdbnurtejex")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadContainerAutoProtectionIntent'.
     */
    @JvmName("yfjivuaugfsqenmt")
    public suspend fun protectionIntentItemType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionIntentItemType = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("ptnqslhkdurxoeay")
    public suspend fun protectionState(`value`: Either<String, ProtectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("rwsubxgebjoucxmq")
    public fun protectionState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("nwspxpdbcrvjghdh")
    public fun protectionState(`value`: ProtectionStatus) {
        val toBeMapped = Either.ofRight<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("lbkwfjoycfohdnmu")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    internal fun build(): AzureWorkloadContainerAutoProtectionIntentArgs =
        AzureWorkloadContainerAutoProtectionIntentArgs(
            backupManagementType = backupManagementType,
            itemId = itemId,
            policyId = policyId,
            protectionIntentItemType = protectionIntentItemType ?: throw
                PulumiNullFieldException("protectionIntentItemType"),
            protectionState = protectionState,
            sourceResourceId = sourceResourceId,
        )
}
